
From: Anton Blanchard <anton@samba.org>

My recent change to dynamically allocate emergency stacks broke JS20 blades
and POWER5.  Since we use the emergency stacks in real mode during
secondary CPU bringup they must be below the RMO.

Signed-off-by: Anton Blanchard <anton@samba.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/ppc64/kernel/setup.c |    9 ++++++++-
 1 files changed, 8 insertions(+), 1 deletion(-)

diff -puN arch/ppc64/kernel/setup.c~ppc64-fix-power5-js20-smp-init arch/ppc64/kernel/setup.c
--- 25/arch/ppc64/kernel/setup.c~ppc64-fix-power5-js20-smp-init	2004-09-06 21:47:03.996327744 -0700
+++ 25-akpm/arch/ppc64/kernel/setup.c	2004-09-06 21:47:04.000327136 -0700
@@ -724,16 +724,23 @@ static void __init irqstack_early_init(v
  */
 static void __init emergency_stack_init(void)
 {
+	unsigned long limit;
 	unsigned int i;
 
 	/*
 	 * Emergency stacks must be under 256MB, we cannot afford to take
 	 * SLB misses on them. The ABI also requires them to be 128-byte
 	 * aligned.
+	 *
+	 * Since we use these as temporary stacks during secondary CPU
+	 * bringup, we need to get at them in real mode. This means they
+	 * must also be within the RMO region.
 	 */
+	limit = min(0x10000000UL, lmb.rmo_size);
+
 	for_each_cpu(i)
 		paca[i].emergency_sp = __va(lmb_alloc_base(PAGE_SIZE, 128,
-						0x10000000)) + PAGE_SIZE;
+						limit)) + PAGE_SIZE;
 }
 
 /*
_
